Check

Enum Check 

pub enum Check {
    NoNode,
    BadVersion {
        expected: i32,
    },
}
Errors that may cause a check request to fail.

Variants



NoNode

No node exists with the given path.



BadVersion

The target node has a different version than was specified by the call to check.

Fields

expected: i32

The expected node version.