pub enum Create {
NodeExists,
NoNode,
NoChildrenForEphemerals,
InvalidAcl,
}Expand description
Errors that may cause a create request to fail.
Variants
NodeExists
A node with the given path already exists.
NoNode
The parent node of the given path does not exist.
NoChildrenForEphemerals
The parent node of the given path is ephemeral, and cannot have children.
InvalidAcl
The given ACL is invalid.