Multi

Enum Multi 

pub enum Multi {
    Delete {
        source: Delete,
    },
    SetData {
        source: SetData,
    },
    Create {
        source: Create,
    },
    Check {
        source: Check,
    },
    RolledBack,
    Skipped,
}
The result of a failed multi request.

Variants



Delete

A failed delete request.

Fields

source: Delete

The source error.



SetData

A failed set_data request.

Fields

source: SetData

The source error.



Create

A failed create request.

Fields

source: Create

The source error.



Check

A failed check request.

Fields

source: Check

The source error.



RolledBack

The request would have succeeded, but a later request in the multi batch failed and caused this request to get rolled back.



Skipped

The request was skipped because an earlier request in the multi batch failed. It is unknown whether this request would have succeeded.