SetData

Enum SetData 

pub enum SetData {
    NoNode,
    BadVersion {
        expected: i32,
    },
    NoAuth,
}
Errors that may cause a set_data request to fail.

Variants



NoNode

No node exists with the given path.



BadVersion

The target node has a different version than was specified by the call to set_data.

Fields

expected: i32

The expected node version.



NoAuth

The target node’s permission does not accept data modification or requires different authentication to be altered.