pub enum Multi {
Delete {
source: Delete,
},
SetData {
source: SetData,
},
Create {
source: Create,
},
Check {
source: Check,
},
RolledBack,
Skipped,
}Expand description
The result of a failed multi request.
Variants
Delete
A failed delete request.
SetData
A failed set_data request.
Create
A failed create request.
Check
A failed check request.
RolledBack
The request would have succeeded, but a later request in the multi
batch failed and caused this request to get rolled back.
Skipped
The request was skipped because an earlier request in the multi batch
failed. It is unknown whether this request would have succeeded.